@@ -5,13 +5,15 @@ class InvalidDocumentException(Exception):
         message -- explanation of the error
         causes -- list of errors which caused this document to be invalid
     """
+
     def __init__(self, causes):
         self._causes = sorted(causes)
 
     @property
     def message(self):
-        return 'Invalid Serverless Application Specification document. Number of errors found: {}.'\
-            .format(len(self.causes))
+        return "Invalid Serverless Application Specification document. Number of errors found: {}.".format(
+            len(self.causes)
+        )
 
     @property
     def causes(self):
@@ -23,6 +25,7 @@ class DuplicateLogicalIdException(Exception):
     Attributes:
         message -- explanation of the error
     """
+
     def __init__(self, logical_id, duplicate_id, type):
         self._logical_id = logical_id
         self._duplicate_id = duplicate_id
@@ -30,10 +33,13 @@ class DuplicateLogicalIdException(Exception):
 
     @property
     def message(self):
-        return 'Transforming resource with id [{logical_id}] attempts to create a new' \
-               ' resource with id [{duplicate_id}] and type "{type}". A resource with that id already' \
-               ' exists within this template. Please use a different id for that resource.'.format(
-                   logical_id=self._logical_id, type=self._type, duplicate_id=self._duplicate_id)
+        return (
+            "Transforming resource with id [{logical_id}] attempts to create a new"
+            ' resource with id [{duplicate_id}] and type "{type}". A resource with that id already'
+            " exists within this template. Please use a different id for that resource.".format(
+                logical_id=self._logical_id, type=self._type, duplicate_id=self._duplicate_id
+            )
+        )
 
 
 class InvalidTemplateException(Exception):
@@ -57,6 +63,7 @@ class InvalidResourceException(Exception):
     Attributes:
         message -- explanation of the error
     """
+
     def __init__(self, logical_id, message):
         self._logical_id = logical_id
         self._message = message
@@ -66,7 +73,7 @@ class InvalidResourceException(Exception):
 
     @property
     def message(self):
-        return 'Resource with id [{}] is invalid. {}'.format(self._logical_id, self._message)
+        return "Resource with id [{}] is invalid. {}".format(self._logical_id, self._message)
 
 
 class InvalidEventException(Exception):
@@ -75,16 +82,17 @@ class InvalidEventException(Exception):
     Attributes:
         message -- explanation of the error
     """
+
     def __init__(self, event_id, message):
         self._event_id = event_id
         self._message = message
 
     @property
     def message(self):
-        return 'Event with id [{}] is invalid. {}'.format(self._event_id, self._message)
+        return "Event with id [{}] is invalid. {}".format(self._event_id, self._message)
 
 
-def prepend(exception, message, end=': '):
+def prepend(exception, message, end=": "):
     """Prepends the first argument (i.e., the exception message) of the a BaseException with the provided message.
     Useful for reraising exceptions with additional information.
 
@@ -93,6 +101,6 @@ def prepend(exception, message, end=': '):
     :param str end: the separator to add to the end of the provided message
     :returns: the exception
     """
-    exception.args = exception.args or ('',)
-    exception.args = (message + end + exception.args[0], ) + exception.args[1:]
+    exception.args = exception.args or ("",)
+    exception.args = (message + end + exception.args[0],) + exception.args[1:]
     return exception
